@@ -23,6 +23,7 @@
 #include "ephy-favicon-cache.h"
 #include "mozilla-embed-single.h"
 #include "ephy-debug.h"
+#include "downloader-view.h"
 
 #include <string.h>
 
@@ -30,7 +31,6 @@ struct EphyEmbedShellPrivate
 {
 	EphyHistory *global_history;
 	DownloaderView *downloader_view;
-	GList *embeds;
 	EphyFaviconCache *favicon_cache;
 	EphyEmbedSingle *embed_single;
 };
@@ -44,7 +44,7 @@ ephy_embed_shell_finalize (GObject *object);
 
 static EphyHistory *
 impl_get_global_history (EphyEmbedShell *shell);
-static DownloaderView *
+static GObject *
 impl_get_downloader_view (EphyEmbedShell *shell);
 
 static GObjectClass *parent_class = NULL;
@@ -101,8 +101,6 @@ ephy_embed_shell_init (EphyEmbedShell *ges)
 
 	ges->priv->global_history = NULL;
 	ges->priv->downloader_view = NULL;
-	ges->priv->embeds = NULL;
-
 	ges->priv->favicon_cache = NULL;
 }
 
@@ -171,7 +169,7 @@ ephy_embed_shell_new (const char *type)
  *
  * Return value: the favicons cache
  **/
-EphyFaviconCache *
+GObject *
 ephy_embed_shell_get_favicon_cache (EphyEmbedShell *ees)
 {
 	if (ees->priv->favicon_cache == NULL)
@@ -179,37 +177,7 @@ ephy_embed_shell_get_favicon_cache (EphyEmbedShell *ees)
 		ees->priv->favicon_cache = ephy_favicon_cache_new ();
 	}
 
-	return ees->priv->favicon_cache;
-}
-
-void
-ephy_embed_shell_add_embed (EphyEmbedShell *ges,
-                            EphyEmbed *embed)
-{
-	ges->priv->embeds = g_list_append (ges->priv->embeds, embed);
-}
-
-void
-ephy_embed_shell_remove_embed (EphyEmbedShell *ges,
-                               EphyEmbed *embed)
-{
-	ges->priv->embeds = g_list_remove (ges->priv->embeds, embed);
-}
-
-EphyEmbed *
-ephy_embed_shell_get_active_embed (EphyEmbedShell *ges)
-{
-	GList *list = ges->priv->embeds;
-
-        g_return_val_if_fail (ges->priv->embeds != NULL, NULL);
-
-        return EPHY_EMBED (list->data);
-}
-
-GList *
-ephy_embed_shell_get_embeds (EphyEmbedShell *ges)
-{
-	return ges->priv->embeds;
+	return G_OBJECT (ees->priv->favicon_cache);
 }
 
 EphyHistory *
@@ -219,7 +187,7 @@ ephy_embed_shell_get_global_history (EphyEmbedShell *shell)
         return klass->get_global_history (shell);
 }
 
-DownloaderView *
+GObject *
 ephy_embed_shell_get_downloader_view (EphyEmbedShell *shell)
 {
 	EphyEmbedShellClass *klass = EPHY_EMBED_SHELL_GET_CLASS (shell);
@@ -229,9 +197,24 @@ ephy_embed_shell_get_downloader_view (EphyEmbedShell *shell)
 EphyEmbedSingle *
 ephy_embed_shell_get_embed_single (EphyEmbedShell *shell)
 {
+
 	if (!shell->priv->embed_single)
 	{
-		shell->priv->embed_single = ephy_embed_single_new ("mozilla");
+		EphyEmbedSingle *single;
+		gboolean res;
+
+		single = mozilla_embed_single_new ();
+		res = mozilla_embed_single_init_services
+			(MOZILLA_EMBED_SINGLE (single));
+
+		if (res)
+		{
+			shell->priv->embed_single = single;
+		}
+		else
+		{
+			g_object_unref (single);
+		}
 	}
 
 	return shell->priv->embed_single;
@@ -248,7 +231,7 @@ impl_get_global_history (EphyEmbedShell *shell)
 	return shell->priv->global_history;
 }
 
-static DownloaderView *
+static GObject *
 impl_get_downloader_view (EphyEmbedShell *shell)
 {
 	if (!shell->priv->downloader_view)
@@ -259,6 +242,6 @@ impl_get_downloader_view (EphyEmbedShell *shell)
 			 (gpointer *)&shell->priv->downloader_view);
 	}
 
-	return shell->priv->downloader_view;
+	return G_OBJECT (shell->priv->downloader_view);
 }
 
