@@ -61,8 +61,6 @@ char         *toolbar_get_location              (Toolbar *t);
 void          toolbar_set_location              (Toolbar *t,
 						 const char *location);
 
-void	      toolbar_edit_location		(Toolbar *t);
-
 void	      toolbar_activate_location		(Toolbar *t);
 
 void	      toolbar_clear_location_history	(Toolbar *t);
@@ -73,6 +71,12 @@ void	      toolbar_update_navigation_actions (Toolbar *t,
 						 gboolean back,
 						 gboolean forward,
 						 gboolean up);
+void	      toolbar_update_zoom		(Toolbar *t,
+						 float zoom);
+
+void	      toolbar_set_visibility		(Toolbar *t,
+						 gboolean normal_toolbars,
+						 gboolean bmk_toolbars);
 
 G_END_DECLS
 
